;*****************************************************************************
;  RC5 EDU graphs the delta BCS radiance versus dn, SNR vs delta BCS radiance
;  and NEdT vs delta BCS radiance.
;
;  Output:
;  1) postscript file containing graphs.
;  
;  v1.0 - 04/02/2008 - Jeff McIntire
;*****************************************************************************

PRO RC5_view, infile

close,/all

restore,'/home/jmcintire/VIIRS_Data/general.TEB.sav'

;*****************************************************************************
;  Read in data.
;*****************************************************************************

nlines=File_Lines(infile)
ab=''
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.
rvs_in=strarr(1)
param_in=strarr(1)
rsrpath=strarr(1)
fnumber=fltarr(1)

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
readf,lun,rvs_in
readf,lun,param_in
readf,lun,rsrpath
readf,lun,fnumber
Free_Lun,lun

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-2]+'.'+a2[a3-1]+'.ps'
device,/landscape,filename=outfname,/color
!p.multi=[0,2,1]

infname=strarr(4)
infname[0]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rad.sav'
infname[1]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.dn.sav'
infname[2]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rg.sav'
infname[3]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.snr.sav'
check=FILE_SEARCH(infname[0])
IF check EQ '' THEN BEGIN
	print,'No file is found.',infname[0]
	goto,skip_loop
ENDIF
FOR i=0, 3 DO BEGIN
	print,'Processing file:',infname[i]
	restore,infname[i]
ENDFOR

D=findgen(4000)
E=findgen(30000)
F=fltarr(30000)

;*****************************************************************************
;  Plot delta BCS radiance versus dn with fits (linear poly_fit, quadratic pol_fit,
;  and cubic poly_fit).
;*****************************************************************************

title=strarr(4)

!p.multi=[0,3,3]
!p.position=0

FOR b=0, nbands_TEB-1 DO BEGIN

	title1='Detector Variation in Gain'
	title2=band_name_TEB[b]+', HAM=1 (quadratic poly_fit)'

	ymax=max(rg_1[b,0,0:detectors_TEB[b]-1,0,1,4,0],min=ymin)

	plot,D[0:detectors_TEB[b]-1]+1,rg_1[b,0,0:detectors_TEB[b]-1,0,1,4,0],yrange=[ymin,ymax],xrange=[0,detectors_TEB[b]], $
		xtit='Detector',ytit='Gain',title=title2,charsize=1.2,charthick=5,/nodata
	oplot,D[0:detectors_TEB[b]-1]+1,rg_1[b,0,0:detectors_TEB[b]-1,0,1,4,0],symsize=1,color=lcol[b],psym=symbol[b]
	oplot,D[0:detectors_TEB[b]-1]+1,rg_1[b,0,0:detectors_TEB[b]-1,0,1,4,0],color=lcol[b]

ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5

title=strarr(4)

!p.multi=[0,2,3]

FOR b=0, nbands_TEB-1 DO BEGIN
	!p.position=0

	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			IF band_type_TEB[b] EQ 0 THEN BEGIN
				title1=band_name_TEB[b]+': dn vs dL_BCS'
				title[0]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (linear poly_fit)'
				title[1]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic poly_fit)'
				title[2]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (cubic poly_fit)'
			ENDIF
			IF band_type_TEB[b] EQ 1 THEN BEGIN
				title1=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+': dn vs dL_BCS'
				title[0]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (linear poly_fit)'
				title[1]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic poly_fit)'
				title[2]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (cubic poly_fit)'
			ENDIF

			xmax=max(L_max_TEB[b,0])
			ymax=max(dn[*,b,ih,*,is,0])

			FOR j=0, 2 DO BEGIN
				plot,rad_BCS[*,b,ih,1,is,0],dn[*,b,ih,1,is,0],yrange=[0,ymax],xrange=[0,xmax], $
					xtit='dL_BCS',ytit='dn',title=title[j],charsize=1.2,charthick=5,/nodata

				FOR id=0, detectors_TEB[b]-1 DO BEGIN
			;	FOR id=0, 3 DO BEGIN
					oplot,rad_BCS[*,b,ih,id,is,0],dn[*,b,ih,id,is,0],symsize=1,color=lcol[id],psym=symbol[id]
					IF j EQ 0 THEN oplot,rg_1[b,ih,id,is,0,3,0]+rg_1[b,ih,id,is,1,3,0]*D,color=lcol[id]
					IF j EQ 1 THEN oplot,rg_1[b,ih,id,is,0,4,0]+rg_1[b,ih,id,is,1,4,0]*D $
						+rg_1[b,ih,id,is,2,4,0]*D^2,color=lcol[id]
					IF j EQ 2 THEN oplot,rg_1[b,ih,id,is,0,5,0]+rg_1[b,ih,id,is,1,5,0]*D $
						+rg_1[b,ih,id,is,2,5,0]*D^2+rg_1[b,ih,id,is,3,5,0]*D^3,color=lcol[id]
				ENDFOR
				oplot,[L_max_TEB[b,0]/fnumber,L_max_TEB[b,0]/fnumber],[-100,10000], $
					symsize=1,color=lcol[1],linestyle=2,thick=2
				oplot,[L_typ_TEB[b,0]/fnumber,L_typ_TEB[b,0]/fnumber],[-100,10000], $
					symsize=1,color=lcol[2],linestyle=2,thick=2
				oplot,[L_min_TEB[b,0]/fnumber,L_min_TEB[b,0]/fnumber],[-100,10000], $
					symsize=1,color=lcol[3],linestyle=2,thick=2

				ymax2=max(L_max_TEB[b,0])

				plot,rad_BCS[*,b,ih,0,is,0],dL_fit[*,b,ih,0,is,j,0],xtit='dL_BCS',ytit='Fitting Residual', $
					xrange=[0,ymax2],yrange=[-0.1,0.1],title=title[j],charsize=1.2,charthick=5,/nodata

				FOR id=0, detectors_TEB[b]-1 DO BEGIN
			;	FOR id=0, 3 DO BEGIN
					oplot,rad_BCS[*,b,ih,id,is,0],dL_fit[*,b,ih,id,is,j,0],symsize=1,color=lcol[id], $
						psym=symbol[id]
					oplot,rad_BCS[*,b,ih,id,is,0],dL_fit[*,b,ih,id,is,j,0],color=lcol[id]
				ENDFOR
				oplot,[L_max_TEB[b,0]/fnumber,L_max_TEB[b,0]/fnumber],[-100,10000], $
					symsize=1,color=lcol[1],linestyle=2,thick=2
				oplot,[L_typ_TEB[b,0]/fnumber,L_typ_TEB[b,0]/fnumber],[-100,10000], $
					symsize=1,color=lcol[2],linestyle=2,thick=2
				oplot,[L_min_TEB[b,0]/fnumber,L_min_TEB[b,0]/fnumber],[-100,10000], $
					symsize=1,color=lcol[3],linestyle=2,thick=2
			ENDFOR
			XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
			IF band_type_TEB[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
			IF band_type_TEB[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
		ENDFOR
	ENDFOR
ENDFOR

;*****************************************************************************
;  Plot SNR versus delta BCS radiance with (cubic polynomial) fits and residuals.
;*****************************************************************************

!p.multi=[0,3,3]
!p.position=0

FOR b=0, nbands_TEB-1 DO BEGIN

	title1='Detector Variation in Gain'
	title2=band_name_TEB[b]+', HAM=1 (quadratic poly_fit)'

	ymax=max(SNR_typ[b,0,0:detectors_TEB[b]-1,0,0,1,0],min=ymin)

	plot,D[0:detectors_TEB[b]-1]+1,SNR_typ[b,0,0:detectors_TEB[b]-1,0,0,1,0],yrange=[ymin,ymax], $
		xrange=[0,detectors_TEB[b]],xtit='Detector',ytit='SNR at L_TYP',title=title2,charsize=1.2,charthick=5,/nodata
	oplot,D[0:detectors_TEB[b]-1]+1,SNR_typ[b,0,0:detectors_TEB[b]-1,0,0,1,0],symsize=1,color=lcol[b],psym=symbol[b]
	oplot,D[0:detectors_TEB[b]-1]+1,SNR_typ[b,0,0:detectors_TEB[b]-1,0,0,1,0],color=lcol[b]

ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,2,2]

FOR b=0, nbands_TEB-1 DO BEGIN
	!p.position=0

	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			IF band_type_TEB[b] EQ 0 THEN BEGIN
				title1=band_name_TEB[b]+': SNR vs dL_BCS'
				title[0]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (function powell)'
				title[1]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic powell)'
			;	title[2]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (weighted function powell)'
				title[2]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)
				title[3]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (weighted quadratic powell)'
			ENDIF
			IF band_type_TEB[b] EQ 1 THEN BEGIN
				title1=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+': SNR vs dL_BCS'
				title[0]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (function powell)'
				title[1]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic powell)'
			;	title[2]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
			;		+' (weighted function powell)'
				title[2]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2)
				title[3]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (weighted quadratic powell)'
			ENDIF

			ymax=max(SNR[*,b,ih,*,is])
			xmax=max(0.4444*rad_BCS[*,b,ih,0,is,0])

			j=0
			FOR ifit=0, 1 DO BEGIN
				FOR ifit2=0, 1 DO BEGIN
					plot,0.4444*rad_BCS[*,b,ih,0,is,0],SNR[*,b,ih,1,is],yrange=[0,ymax],xrange=[0,xmax], $
						xtit='dL_BCS',ytit='SNR',title=title[j],charsize=1.2,charthick=5,/nodata

					F[*]=0.1*E[*]
					FOR id=0, detectors_TEB[b]-1 DO BEGIN
						oplot,0.4444*rad_BCS[*,b,ih,id,is,0],SNR[*,b,ih,id,is],symsize=1, $
							color=lcol[id],psym=symbol[id]
						IF ifit2 EQ 0 THEN oplot,F[*],F[*]/sqrt(snr_1[b,ih,id,is,0,ifit2,ifit] $
							+snr_1[b,ih,id,is,1,ifit2,ifit]*F[*] $
							+snr_1[b,ih,id,is,2,ifit2,ifit]*F[*]^2),color=lcol[id]
						IF ifit2 EQ 1 THEN oplot,F[*],snr_1[b,ih,id,is,0,ifit2,ifit] $
							+snr_1[b,ih,id,is,1,ifit2,ifit]*F[*] $
							+snr_1[b,ih,id,is,2,ifit2,ifit]*F[*]^2,color=lcol[id]
					ENDFOR
					oplot,[L_max_TEB[b,0],L_max_TEB[b,0]],[-100,10000],symsize=1,color=lcol[1], $
						linestyle=2,thick=1.5
					oplot,[L_typ_TEB[b,0],L_typ_TEB[b,0]],[-100,10000],symsize=1,color=lcol[2], $
						linestyle=2,thick=1.5
					oplot,[L_min_TEB[b,0],L_min_TEB[b,0]],[-100,10000],symsize=1,color=lcol[3], $
						linestyle=2,thick=1.5
					j=j+1
				ENDFOR
			ENDFOR
			XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
			IF band_type_TEB[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
			IF band_type_TEB[b] EQ 0 THEN set_legend,1,chname,lcol,symbol

			; Start the fitting residual plots.
			j=0
			FOR ifit=0, 1 DO BEGIN
				FOR ifit2=0, 1 DO BEGIN
					plot,0.4444*rad_BCS[*,b,ih,0,is,0],snr_fit[*,b,ih,0,is,1,ifit],xtit='rad_BCS', $
						ytit='SNR Fitting Residual',xrange=[0,xmax],yrange=[-0.5,0.5],title=title[j], $
						charsize=1.2,charthick=5,/nodata

					FOR id=0, detectors_TEB[b]-1 DO BEGIN
						oplot,0.4444*rad_BCS[*,b,ih,id,is,0],snr_fit[*,b,ih,id,is,ifit2,ifit], $
							symsize=1,color=lcol[id],psym=symbol[id]
					;	oplot,0.4444*rad_BCS[0:ncollects-1,b,ih,id,is,0],snr_fit[0:ncollects-1,b,ih,id,is,ifit2,ifit], $
					;		symsize=1,color=lcol[id],psym=symbol[id]
if ifit eq 1 and ifit2 eq 0 and ih eq 0 and b eq 2 and id eq 2 then print,snr_fit[*,b,ih,id,is,ifit2,ifit]
						oplot,0.4444*rad_BCS[*,b,ih,id,is,0],snr_fit[*,b,ih,id,is,ifit2,ifit], $
							color=lcol[id]
					ENDFOR
					oplot,[L_max_TEB[b,0],L_max_TEB[b,0]],[-100,10000],symsize=1,color=lcol[1], $
						linestyle=2,thick=1.5
					oplot,[L_typ_TEB[b,0],L_typ_TEB[b,0]],[-100,10000],symsize=1,color=lcol[2], $
						linestyle=2,thick=1.5
					oplot,[L_min_TEB[b,0],L_min_TEB[b,0]],[-100,10000],symsize=1,color=lcol[3], $
						linestyle=2,thick=1.5
					j=j+1
				ENDFOR
			ENDFOR
			XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
			IF band_type_TEB[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
			IF band_type_TEB[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
		ENDFOR
	ENDFOR
ENDFOR

;*****************************************************************************
;  NEdT.
;*****************************************************************************

NEDT_spec=[[2.5,1.5,0.396,0.107,0.091,0.07,0.072,0.072],[0,0,0,0.423,0,0,0,0]]

!p.multi=[0,3,3]
!p.position=0

FOR b=0, nbands_TEB-1 DO BEGIN

	title1='Detector Variation in Gain'
	title2=band_name_TEB[b]+', HAM=1 (quadratic poly_fit)'

	ymax=max(NEdT_spec[b,0]*1.1)

	plot,D[0:detectors_TEB[b]-1]+1,NEdT_typ[b,0,0:detectors_TEB[b]-1,0,0,1,0],yrange=[0,ymax], $
		xrange=[0,detectors_TEB[b]],xtit='Detector',ytit='NEdt at L_TYP',title=title2,charsize=1.2,charthick=5,/nodata
	oplot,D[0:detectors_TEB[b]-1]+1,NEdT_typ[b,0,0:detectors_TEB[b]-1,0,0,1,0],symsize=1,color=lcol[b],psym=symbol[b]
	oplot,D[0:detectors_TEB[b]-1]+1,NEdT_typ[b,0,0:detectors_TEB[b]-1,0,0,1,0],color=lcol[b]
	oplot,[0,50],[NEDT_spec[b,0],NEDT_spec[b,0]],color=lcol[1],linestyle=2

ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,2,2]

FOR b=0, nbands_TEB-1 DO BEGIN
	!p.position=0

	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			IF band_type_TEB[b] EQ 0 THEN BEGIN
				title1=band_name_TEB[b]+': NEdT vs dL_BCS'
				title[0]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (function powell)'
				title[1]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic powell)'
		;		title[2]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (weighted function powell)'
				title[2]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)
				title[3]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (weighted quadratic powell)'
			ENDIF
			IF band_type_TEB[b] EQ 1 THEN BEGIN
				title1=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+': NEdT vs dL_BCS'
				title[0]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (function powell)'
				title[1]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic powell)'
		;		title[2]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
		;			+' (weighted function powell)'
				title[2]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2)
				title[3]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (weighted quadratic powell)'
			ENDIF

			xmax=max(0.4444*rad_BCS[*,b,ih,0,is,0])
		;	xmax=max(L_max_TEB[b,0])
print,fnumber
			j=0
			FOR ifit=0, 1 DO BEGIN
				FOR ifit2=0, 1 DO BEGIN
					plot,0.4444*rad_BCS[*,b,ih,0,is],NEdT[*,b,ih,0,is,1,ifit],xtit='dL_BCS',ytit='NEdT', $
						yrange=[0,1.0],xrange=[0,xmax],title=title[j],charsize=1.2,charthick=5,/nodata

					FOR id=0, detectors_TEB[b]-1 DO BEGIN
						oplot,0.4444*rad_BCS[*,b,ih,id,is],NEdT[*,b,ih,id,is,ifit2,ifit],symsize=1, $
							color=lcol[id],psym=symbol[id]
						oplot,0.4444*rad_BCS[*,b,ih,id,is],NEdT[*,b,ih,id,is,ifit2,ifit],color=lcol[id]
					ENDFOR
					oplot,[L_max_TEB[b,0],L_max_TEB[b,0]],[-100,100],symsize=1,color=lcol[1], $
						linestyle=2,thick=1.5
					oplot,[L_typ_TEB[b,0],L_typ_TEB[b,0]],[-100,100],symsize=1,color=lcol[2], $
						linestyle=2,thick=1.5
					oplot,[L_min_TEB[b,0],L_min_TEB[b,0]],[-100,100],symsize=1,color=lcol[3], $
						linestyle=2,thick=1.5
					j=j+1
				ENDFOR
			ENDFOR
			XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
			IF band_type_TEB[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
			IF band_type_TEB[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
		ENDFOR
	ENDFOR
ENDFOR

skip_loop:

END
